@@ -40,7 +40,7 @@ that country.
 """
 
 from stdnum.exceptions import *
-from stdnum.util import clean, get_vat_module
+from stdnum.util import clean, get_vat_module, get_soap_client
 
 
 country_codes = set([
@@ -117,19 +117,8 @@ def _get_client():  # pragma: no cover (no tests for this function)
     # this function isn't automatically tested because the functions using
     # it are not automatically tested
     global _vies_client
-    if not _vies_client:
-        try:
-            from urllib import getproxies
-        except ImportError:
-            from urllib.request import getproxies
-        # try suds first
-        try:
-            from suds.client import Client
-            _vies_client = Client(vies_wsdl, proxy=getproxies()).service
-        except ImportError:
-            # fall back to using pysimplesoap
-            from pysimplesoap.client import SoapClient
-            _vies_client = SoapClient(wsdl=vies_wsdl, proxy=getproxies())
+    if _vies_client is None:
+        _vies_client = get_soap_client(vies_wsdl)
     return _vies_client
 
 
@@ -154,6 +143,6 @@ def check_vies_approx(number, requester):  # pragma: no cover
     # network access for the tests and unnecessarily load the VIES website
     number = compact(number)
     requester = compact(requester)
-    return _get_client.checkVatApprox(
+    return _get_client().checkVatApprox(
         countryCode=number[:2], vatNumber=number[2:],
         requesterCountryCode=requester[:2], requesterVatNumber=requester[2:])
