@@ -17,11 +17,15 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""Onderwijsnummer (Dutch school number).
+"""Onderwijsnummer (Dutch student school number).
 
-The onderwijsnummers (school number) is very similar to the BSN (Dutch
-national identification number) but for students without a BSN. It uses a
-small variation of the BSN checksum.
+The onderwijsnummers (education number) is very similar to the BSN (Dutch
+national identification number) for students without a BSN. It uses a
+checksum mechanism similar to the BSN.
+
+More information:
+
+* https://nl.wikipedia.org/wiki/Onderwijsnummer
 
 >>> validate('1012.22.331')
 '101222331'
