@@ -1,7 +1,7 @@
 # util.py - common utility functions
 # coding: utf-8
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2016 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -23,6 +23,11 @@
 This module is meant for internal use by stdnum modules and is not
 guaranteed to remain stable and as such not part of the public API of
 stdnum.
+
+>>> get_vat_module('nl').__name__
+'stdnum.nl.btw'
+>>> get_vat_module('is').__name__
+'stdnum.is_.vsk'
 """
 
 import pkgutil
@@ -34,7 +39,7 @@ import unicodedata
 from stdnum.exceptions import *
 
 
-_strip_doctest_re = re.compile('^>>> .*\Z', re.DOTALL | re.MULTILINE)
+_strip_doctest_re = re.compile(r'^>>> .*\Z', re.DOTALL | re.MULTILINE)
 
 
 def _mk_char_map(mapping):
@@ -56,7 +61,8 @@ _char_map = dict(_mk_char_map({
     'HYPHEN BULLET,MACRON,MODIFIER LETTER MINUS SIGN,FULLWIDTH MACRON,'
     'OGHAM SPACE MARK,SUPERSCRIPT MINUS,SUBSCRIPT MINUS,MINUS SIGN,'
     'HORIZONTAL LINE EXTENSION,HORIZONTAL SCAN LINE-1,HORIZONTAL SCAN LINE-3,'
-    'HORIZONTAL SCAN LINE-7,HORIZONTAL SCAN LINE-9,STRAIGHTNESS': '-',
+    'HORIZONTAL SCAN LINE-7,HORIZONTAL SCAN LINE-9,STRAIGHTNESS':
+        '-',
     'ASTERISK,ARABIC FIVE POINTED STAR,SYRIAC HARKLEAN ASTERISCUS,'
     'FLOWER PUNCTUATION MARK,VAI FULL STOP,SMALL ASTERISK,FULLWIDTH ASTERISK,'
     'ASTERISK OPERATOR,STAR OPERATOR,HEAVY ASTERISK,LOW ASTERISK,'
@@ -64,11 +70,13 @@ _char_map = dict(_mk_char_map({
     'TEARDROP-SPOKED ASTERISK,OPEN CENTRE TEARDROP-SPOKED ASTERISK,'
     'HEAVY TEARDROP-SPOKED ASTERISK,EIGHT TEARDROP-SPOKED PROPELLER ASTERISK,'
     'HEAVY EIGHT TEARDROP-SPOKED PROPELLER ASTERISK,'
-    'ARABIC FIVE POINTED STAR': '*',
+    'ARABIC FIVE POINTED STAR':
+        '*',
     'COMMA,ARABIC COMMA,SINGLE LOW-9 QUOTATION MARK,IDEOGRAPHIC COMMA,'
     'ARABIC DECIMAL SEPARATOR,ARABIC THOUSANDS SEPARATOR,PRIME,RAISED COMMA,'
     'PRESENTATION FORM FOR VERTICAL COMMA,SMALL COMMA,'
-    'SMALL IDEOGRAPHIC COMMA,FULLWIDTH COMMA,CEDILLA': ',',
+    'SMALL IDEOGRAPHIC COMMA,FULLWIDTH COMMA,CEDILLA':
+        ',',
     'FULL STOP,MIDDLE DOT,GREEK ANO TELEIA,ARABIC FULL STOP,'
     'IDEOGRAPHIC FULL STOP,SYRIAC SUPRALINEAR FULL STOP,'
     'SYRIAC SUBLINEAR FULL STOP,SAMARITAN PUNCTUATION NEQUDAA,'
@@ -78,17 +86,28 @@ _char_map = dict(_mk_char_map({
     'SMALL FULL STOP,FULLWIDTH FULL STOP,HALFWIDTH KATAKANA MIDDLE DOT,'
     'AEGEAN WORD SEPARATOR DOT,PHOENICIAN WORD SEPARATOR,'
     'KHAROSHTHI PUNCTUATION DOT,DOT ABOVE,ARABIC SYMBOL DOT ABOVE,'
-    'ARABIC SYMBOL DOT BELOW,BULLET OPERATOR,DOT OPERATOR': '.',
+    'ARABIC SYMBOL DOT BELOW,BULLET OPERATOR,DOT OPERATOR':
+        '.',
     'SOLIDUS,SAMARITAN PUNCTUATION ARKAANU,FULLWIDTH SOLIDUS,DIVISION SLASH,'
-    'MATHEMATICAL RISING DIAGONAL,BIG SOLIDUS,FRACTION SLASH': '/',
+    'MATHEMATICAL RISING DIAGONAL,BIG SOLIDUS,FRACTION SLASH':
+        '/',
     'COLON,ETHIOPIC WORDSPACE,RUNIC MULTIPLE PUNCTUATION,MONGOLIAN COLON,'
     'PRESENTATION FORM FOR VERTICAL COLON,FULLWIDTH COLON,'
-    'PRESENTATION FORM FOR VERTICAL TWO DOT LEADER,SMALL COLON': ':',
+    'PRESENTATION FORM FOR VERTICAL TWO DOT LEADER,SMALL COLON':
+        ':',
     'SPACE,NO-BREAK SPACE,EN QUAD,EM QUAD,EN SPACE,EM SPACE,'
     'THREE-PER-EM SPACE,FOUR-PER-EM SPACE,SIX-PER-EM SPACE,FIGURE SPACE,'
     'PUNCTUATION SPACE,THIN SPACE,HAIR SPACE,NARROW NO-BREAK SPACE,'
-    'MEDIUM MATHEMATICAL SPACE,IDEOGRAPHIC SPACE': ' ',
-    }))
+    'MEDIUM MATHEMATICAL SPACE,IDEOGRAPHIC SPACE':
+        ' ',
+}))
+
+
+# mapping of country codes to internally used names
+# used in the get_vat_module() function
+_cc_translations = {
+    'el': 'gr', 'is': 'is_',
+}
 
 
 def _clean_chars(number):
@@ -126,9 +145,8 @@ def get_number_modules(base='stdnum'):
     __import__(base)
     module = sys.modules[base]
     for loader, name, is_pkg in pkgutil.walk_packages(
-                    module.__path__, module.__name__ + '.',
-                    onerror=lambda x: None
-                ):
+            module.__path__, module.__name__ + '.',
+            onerror=lambda x: None):
         __import__(name)
         module = sys.modules[name]
         if hasattr(module, 'validate'):
@@ -144,7 +162,7 @@ def get_module_description(module):
     """Return a description of the number."""
     doc = pydoc.splitdoc(pydoc.getdoc(module))[1]
     # remove the doctests
-    return _strip_doctest_re.sub('', doc[1]).strip(),
+    return _strip_doctest_re.sub('', doc).strip()
 
 
 def get_module_list():
@@ -153,3 +171,28 @@ def get_module_list():
             module.__name__.replace('stdnum.', ''),
             get_module_name(module),
         )
+
+
+def get_vat_module(cc):
+    """Find the VAT number module based on the country code."""
+    cc = cc.lower()
+    cc = _cc_translations.get(cc, cc)
+    return __import__('stdnum.%s' % cc, globals(), locals(), ['vat']).vat
+
+
+def get_soap_client(wsdlurl):  # pragma: no cover (no tests for this function)
+    """Get a SOAP client for performing requests."""
+    # this function isn't automatically tested because the functions using
+    # it are not automatically tested
+    try:
+        from urllib import getproxies
+    except ImportError:
+        from urllib.request import getproxies
+    # try suds first
+    try:
+        from suds.client import Client
+        return Client(wsdlurl, proxy=getproxies()).service
+    except ImportError:
+        # fall back to using pysimplesoap
+        from pysimplesoap.client import SoapClient
+        return SoapClient(wsdl=wsdlurl, proxy=getproxies())
